#
# spec file for package whipper
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           whipper
Version:        0.10.0
Release:        bp160.1.6
Summary:        A CD ripper aiming for accuracy over speed
License:        GPL-3.0-or-later
Group:          Productivity/Multimedia/CD/Grabbers
URL:            https://github.com/whipper-team/whipper
Source0:        %{url}/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
# PATCH_UPSTREAM
Patch0:         e0942417a1c267781a8b676789730457dcb2e6fa.patch
BuildRequires:  fdupes
BuildRequires:  gobject-introspection
BuildRequires:  libsndfile-devel
BuildRequires:  python-rpm-macros
BuildRequires:  python3-devel
BuildRequires:  python3-gobject
BuildRequires:  python3-setuptools
BuildRequires:  python3-setuptools_scm
# SECTION test requirements
BuildRequires:  cd-paranoia >= 10.2
BuildRequires:  cdrdao
BuildRequires:  python3-Twisted
BuildRequires:  python3-discid
BuildRequires:  python3-musicbrainzngs
BuildRequires:  python3-mutagen
BuildRequires:  python3-pycdio
BuildRequires:  python3-pytest
BuildRequires:  python3-ruamel.yaml
BuildRequires:  sox
# /SECTION
# nb: there is a difference between cd-paranoia [we want] and
#     cdparanoia [we don't]
Requires:       cd-paranoia >= 10.2
Requires:       cdrdao
Requires:       flac
Requires:       python3-discid
Requires:       python3-gobject
Requires:       python3-musicbrainzngs
Requires:       python3-mutagen
Requires:       python3-pycdio
Requires:       python3-ruamel.yaml
Requires:       sox
Conflicts:      morituri

%description
Whipper is an audio CD ripper that aims for accuracy over speed. It
automatically tags tracks using MusicBrainz data, takes drive offsets into
account, supports AccurateRip, and can rip certain hidden tracks.
Whipper was forked from the Morituri project, after Morituri development halted.

%prep
%autosetup -p1

%build
echo "Version: %{version}" > PKG-INFO
%python3_build

%install
%python3_install
%fdupes %{buildroot}%{python3_sitearch}

%check
# Don't run accurip tests since those needs a network connection to www.accuraterip.com
rm -rf whipper/test/test_common_accurip.py
export PYTHONPATH=%{buildroot}%{python3_sitearch}
pytest whipper/test/

%files
%doc CHANGELOG.md README.md
%license LICENSE
%{_bindir}/accuraterip-checksum
%{_bindir}/whipper
%{python3_sitearch}/whipper
%{python3_sitearch}/accuraterip.cpython*
%{python3_sitearch}/%{name}-%{version}-py%{python3_version}.egg-info
%{_datadir}/metainfo/com.github.whipper_team.Whipper.metainfo.xml

%changelog
* Tue Feb 20 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN
* Sat Nov  6 2021 olaf@aepfle.de
- Package README.md instead of dead symlink README
* Tue Aug 10 2021 Dr. Werner Fink <werner@suse.de>
- Add upstream commit as patch e0942417a1c267781a8b676789730457dcb2e6fa.patch
  * Use custom YAML subclass to be compatible with ruamel_yaml>=0.17
* Mon May 31 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 0.10.0
  * Allow configuring whether to auto close the drive's tray
  * Better error handling for unconfigured drive offset
  * Ability to group multi-disc releases in a single folder
  * Provide option to not use disambiguation in title
  * Save ISRCs from CD TOC
  * Ability to skip unrippable track
  * Grab cover art
  * cdda2wav from cdrtools instead of cdparanoia
  * Full changelog
    https://github.com/whipper-team/whipper/blob/v0.10.0/CHANGELOG.md
* Tue May  4 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Undo single-spec abomination: this is an application, not a
  python module, and we thus do not need all python flavors pulled
  in.
- Add gobject-introspection BuildRequires: the code uses
  gobject-inrtrospection to call out to libraries; by having this
  Build dependency. rpm will add the nescessary requires to the
  package in plus.
* Tue May  4 2021 Dr. Werner Fink <werner@suse.de>
- Make it build again
* Tue Mar 30 2021 Dr. Werner Fink <werner@suse.de>
- Make it build again
* Mon Nov 23 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Use %%pytest instead of /usr/bin/py.test to run tests
* Sun Dec 15 2019 Martin Hauke <mardnh@gmx.de>
- Run testsuite
* Tue Dec 10 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 0.9.0
  Fixed bugs:
  * Fix regression introduced due to Python 3 port
  * Port to Python 3
- Update to version 0.8.0
  Fixed bugs:
  * whipper bails out if MusicBrainz release group doesn’t have a
    type
  * object has no attribute 'working_directory' when running cd
    info
  * Failure to rip CD: "ValueError: could not convert string to
    float: "
  * "AttributeError: Program instance has no attribute '_presult'"
    when ripping
  * Drive analysis fails
  * Eliminate warning "eject: CD-ROM tray close command failed"
  * Flac file permissions
  Closed issues:
  * Separate out Release in log into two value map
  * Network issue #412
  * RequestsDependencyWarning: urllib3 (1.25.2) or chardet (3.0.4)
    doesn't match a supported version
  * Run script after rip
  * Add git/mercurial dependency to the README
  * Include MusicBrainz Release ID in the log file
  * Rip while entering MusicBrainz data
  * Doesn't eject - "eject: unable to eject" (but manual eject
    works)
  * Note in the whipper output/log if development version was used
  * read-toc progress information
  * ripping fails frequently, but not repeatably
  * Look into adding more MusicBrainz identifiers to ripped files
- Use python rpm build macros
- Drop not longer needed patch:
  * whipper-fix-appstream-file-path.patch
* Tue Jan  8 2019 mardnh@gmx.de
- Update from 0.7.0 to 0.7.3
  Fixed bugs:
  * UnicodeEncodeError: 'ascii' codec can't encode characters in
    position 17-18: ordinal not in range(128)
  * Error when parsing log file due to left pad track number #340
  * Failing AccurateRipResponse tests #333
  * CRITICAL:whipper.command.cd:output directory is a finished
    rip output directory #287
  * Possible HTOA error #281
  * Disc template KeyError #279
  * Enhanced CD causes computer to freeze. #256
  * pycdio & libcdio issues #238
  * Unicode issues #215
  * whipper offset find exception #208
  Closed issues:
  * WARNING:whipper.common.program:network error: NetworkError()
  * Write musicbrainz_discid tag when disc is unknown #280
  * Write .toc files in addition to .cue files to support cdrdao
    and non-compliant .cue sheets #214
  Merged pull requests:
  * Discover plugins in system directories too #348
  * Avoid zero padding in logger track numbers #341
  * Update failing AccurateRipResponse tests #334
  * Raise exception when cdparanoia can't read any frames #328
  * Prevent exception in offset find #327
  * Fix template validation error #325
  * Fix UnicodeEncodeError with non ASCII MusicBrainz's catalog
    numbers #323
  * Raise exception if template has invalid variables #322
  * Preserve ToC file generated by cdrdao #321
- Add patch:
  * whipper-fix-appstream-file-path.patch
* Thu Jun  7 2018 sknorr@suse.com
- Update from 0.4.2 to 0.7.0
- Changes: https://github.com/JoeLametta/whipper/releases
- Implemented enhancements:
  - Simple message while reading TOC (gh#JoeLametta/whipper#257)
  - Various ripping issues (gh#JoeLametta/whipper#179)
  - Small readme cleanups (gh#JoeLametta/whipper#250)
  - Remove debug commands, add mblookup command
    (gh#JoeLametta/whipper#249)
  - remove -T/--toc-pickle (gh#JoeLametta/whipper#245)
  - credit four major developers by line count
    (gh#JoeLametta/whipper#243)
  - Removed reference to unused "profile = flac" config option
    (gh#JoeLametta/whipper#99, gh#JoeLametta/whipper#231)
- Fixed bugs:
  - ImportError: libcdio.so.16: cannot open shared object file: No
    such file or directory (gh#JoeLametta/whipper#229)
  - whipper offset find exception (gh#JoeLametta/whipper#208)
  - cd rip is not able to rip the last track
    (gh#JoeLametta/whipper#203)
  - whipper not picking up all settings in whipper.conf
    (gh#JoeLametta/whipper#99)
  - fix CI build error with latest pycdio
    (gh#JoeLametta/whipper#233)
- Closed issues:
  - CD-ROM powers off during rip command
    (gh#JoeLametta/whipper#189)
  - GUI frontend for whipper (gh#JoeLametta/whipper#40)
- Merged pull requests:
  - Remove reference to Copr repository
    (gh#JoeLametta/whipper#248)
  - Revert "Convert docstrings to reStructuredText"
    (gh#JoeLametta/whipper#246)
  - remove radon reports (gh#JoeLametta/whipper#242)
  - read command parameters from config sections
    (gh#JoeLametta/whipper#240)
